*** load data

use data_michigan_rotPanel, clear

foreach var in "ratex" "unemp" "dur" ///
"ratex6" "unemp6" "dur6"{
replace `var'=0 if `var'==3
replace `var'=-1 if `var'==5
replace `var'=. if `var'!=-1 & `var'!=0 & `var'!=1
replace `var'=`var'+2 if `var'!=.
}

replace px1=. if abs(px1)>95
replace px16=. if abs(px1)>95

foreach var in "ratex" "unemp" "dur" "px1"{
gen `var'_diff =  `var'6 - `var'
sum `var'_diff
}

gen Date = ym(yyyy, month)
replace Date = Date + 6
format Date %tm

xtset id Date

merge m:1 Date using shocks
drop _merge

keep if ADshock != .

sort Date
xtset id Date

*** Indicator for being poor

destring income, replace
bys Date: egen median_income = median(income)
gen poor = .
replace poor = 1 if income <= median_income & income!=.
replace poor = 0 if income > median_income & income!=.

*** Indicator for being old

destring age, replace

gen old = .
replace old = 1 if age>64 & age !=.
replace old = 0 if age<65 & age !=.

*** Indicator for college degree

destring eclgrd, replace

gen degree=.
replace degree=0 if eclgrd==5
replace degree=1 if eclgrd==1

*** Indicator for sex

destring sex, replace
replace sex = sex - 1
rename sex female

*** Indicator for recession

gen rec = 0

local recDates ///
1990m7 1990m8 1990m9 1990m10 1990m11 1990m12 1991m1 1991m2 1991m3 ///
2001m3 2001m4 2001m5 2001m6 2001m7 2001m8 2001m9 2001m10 2001m11

foreach recDate in `recDates'{
replace  rec = 1 if Date == tm(`recDate')
}

* Did respondents provide answers in the second interview?

foreach var in "unemp" "px1" "ratex" "dur" {
gen `var'_2answers = .
replace `var'_2answers = 1 if `var'_diff !=.
replace `var'_2answers = 0 if `var'_diff ==.
}

*** Paper estimation

eststo clear
foreach var in "unemp" "px1" "ratex" "dur" {

xi: heckman `var'_diff ADshockMA ASshockMA MPshockMA, select (unemp_2answers = female degree old poor) twostep
xi: heckman `var'_diff ADshockMA ASshockMA MPshockMA female degree old poor, select (unemp_2answers = female degree old poor) twostep
xi: heckman `var'_diff ADshockMA ASshockMA MPshockMA female degree old poor rec, select (unemp_2answers = female degree old poor) twostep
}
