
use data_MS_micro.dta, clear


tostring yyyymm, gen(month)
replace month=substr(month,5,6)
tostring yyyymm, gen(yyyy)
replace yyyy=substr(yyyy,1,4)
destring month yyyy, replace

merge m:1 yyyy month using inflation
keep if _merge==3
drop _merge

merge m:1 yyyy month using shocks
keep if _merge==3
drop _merge

*** keep only possible values

replace px1=. if abs(px1)>95

* categorial inflation expectations

gen inflexp_dir=px1-inflation_ma
gen inflexp_dir_r=round(px1-inflation_ma)
gen inflexpcat=.
replace inflexpcat=0 if inflexp_dir_r==0
replace inflexpcat=1 if inflexp_dir_r>0 & inflexp_dir_r!=.
replace inflexpcat=-1 if inflexp_dir_r<0 & inflexp_dir_r!=.

foreach var in "ratex" "unemp" {
replace `var'=0 if `var'==3
replace `var'=-1 if `var'==5
replace `var'=. if `var'!=-1 & `var'!=0 & `var'!=1
}

*** Calculate the forecast errors

* inflation

gen forecasterr = inflationF12 - px1


*** Theory-consistency classification

*AD consistent contractionary expecations
gen ind_ADconsistent_contr=.
replace ind_ADconsistent_contr=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_ADconsistent_contr=1 if unemp==1 & inflexpcat==-1  & ratex==-1

*AS consistent contractionary expecations
gen ind_ASconsistent_contr=.
replace ind_ASconsistent_contr=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_ASconsistent_contr=1 if unemp==1 & inflexpcat==1  & ratex==1

*MP consistent contractionary expecations
gen ind_MPconsistent_contr=.
replace ind_MPconsistent_contr=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_MPconsistent_contr=1 if unemp==1 & inflexpcat==-1  & ratex==1

*AD consistent expansionary expecations
gen ind_ADconsistent_exp=.
replace ind_ADconsistent_exp=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_ADconsistent_exp=1 if unemp==-1 & inflexpcat==1  & ratex==1

*AS consistent expansionary expecations
gen ind_ASconsistent_exp=.
replace ind_ASconsistent_exp=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_ASconsistent_exp=1 if unemp==-1 & inflexpcat==-1  & ratex==-1

*MP consistent expansionary expecations
gen ind_MPconsistent_exp=.
replace ind_MPconsistent_exp=0 if unemp!=. & inflexpcat!=.  & ratex!=.
replace ind_MPconsistent_exp=1 if unemp==-1 & inflexpcat==1  & ratex==-1

* absolute values

foreach var in "MPshockL1" "ASshockL1" "ADshockL1" ///
"forecasterr"  {
gen `var'_ABS = abs(`var')
}

*** Additional covariates

*** Indicator for being poor

destring income, replace
bys yyyymm: egen median_income = median(income)
gen poor = .
replace poor = 1 if income <= median_income & income!=.
replace poor = 0 if income > median_income & income!=.

*** Indicator for being old

destring age, replace

gen old = .
replace old = 1 if age>64 & age !=.
replace old = 0 if age<65 & age !=.

*** Indicator for college degree

destring eclgrd, replace

gen degree=.
replace degree=0 if eclgrd==5
replace degree=1 if eclgrd==1

*** Indicator for sex

destring sex, replace
replace sex = sex - 1
rename sex female

*** positive/negative shocks

foreach var in "MPshockL1" "ASshockL1" "ADshockL1" {
gen `var'Neg = abs(`var') if `var' < 0
gen `var'Pos = `var' if `var' > 0
}

foreach var in "forecasterr_ABS" {

*** Regress absolute values of forecast errors on single shocks and interactions

*single shocks (positive)

eststo clear

xi: reg `var' ///
ind_ADconsistent_exp##c.ADshockL1Pos ///
female degree old poor
eststo

xi: reg `var' ///
ind_MPconsistent_exp##c.MPshockL1Pos ///
female degree old poor
eststo

xi: reg `var' ///
ind_ASconsistent_exp##c.ASshockL1Pos ///
female degree old poor
eststo

* single shocks (negative)

xi: reg `var' ///
ind_ADconsistent_contr##c.ADshockL1Neg ///
female degree old poor
eststo

xi: reg `var' ///
ind_MPconsistent_contr##c.MPshockL1Neg ///
female degree old poor
eststo

xi: reg `var' ///
ind_ASconsistent_contr##c.ASshockL1Neg ///
female degree old poor
eststo

}
