clear all

%% Figure 3

estmodels = {'Fig3'};
variables = {'FFR', 'INFL', 'U', 'INTERESTexpectations', 'INFLATIONexpectations', 'OUTPUTexpectations', 'CONSUMPTIONexpectations'};

for mm = 1:1
for ss = 1:3
for vv = 1:7
clearvars -except estmodels variables mm ss vv;

shocks = {'MPshock', 'ASshock', 'ADshock', 'residual4', 'residual3', 'residual2', 'residual1'};

ii=1;
model = estmodels{mm};
irf = strcat(shocks{ss},'-',variables{vv});

modelPath = strcat(pwd,'\',model,'/tables/');
presPath = strcat(pwd,'\',model,'_normalized/');

if ~exist(presPath,'dir')
  mkdir(presPath);
end

% getting the IRF-multiplier to have standardized IRFs
uirf=csvread(strcat(modelPath,shocks{ss},'-U.csv'));
uirfmedianresp0=uirf(1,2);

syms x
eqn = uirfmedianresp0*x==1;
irfmultiplier = double(solve(eqn,x));

csvread(strcat(modelPath,irf,'.csv'));
name = ans;

output.irfCTM = name(:,1)*irfmultiplier;
output.irfMedian = name(:,2)*irfmultiplier;
output.irf16 = name(:,5)*irfmultiplier;
output.irf84 = name(:,4)*irfmultiplier;
output.irf05 = name(:,6)*irfmultiplier;
output.irf95 = name(:,3)*irfmultiplier;

if vv<4 || vv==7
    opt.nImpulseHorizon = 24;
else
    opt.nImpulseHorizon = 12;
end

% Plot IRFs in single plots
xAxis = 0:opt.nImpulseHorizon;
xFill = [xAxis,fliplr(xAxis)];
yInnerFill = [output.irf16(1:opt.nImpulseHorizon+1)',fliplr(output.irf84(1:opt.nImpulseHorizon+1)')];
yOuterFill = [output.irf05(1:opt.nImpulseHorizon+1)',fliplr(output.irf95(1:opt.nImpulseHorizon+1)')];


fig = figure(ii);
hold on

set(gca, 'FontSize', 35, 'Position', [.12 .1 .7 .6],'Xtick',0:3:opt.nImpulseHorizon);

fill(xFill,yOuterFill(ii,:),[0.8 0.8 0.8],'edgecolor','none');
fill(xFill,yInnerFill(ii,:),[0.6 0.6 0.6],'edgecolor','none');
plot(0:opt.nImpulseHorizon,output.irfCTM(1:opt.nImpulseHorizon+1,ii),'k--', 'LineWidth', 1);
plot(0:opt.nImpulseHorizon,output.irfMedian(1:opt.nImpulseHorizon+1,ii),'k-', 'LineWidth', 1);
plot(0:opt.nImpulseHorizon,zeros(opt.nImpulseHorizon+1)','k-');
xlim([0 opt.nImpulseHorizon]);


if vv == 1 %FFR
    ylim([-4 4]);
elseif vv == 2 %inflation
    ylim([-7 6]);
elseif vv == 3 %U
    ylim([-1.5 2.5]);
elseif vv == 6 %U expectations
    ylim([-25 30]);
elseif vv == 4 %expectations interest rate
    ylim([-50 30]);
elseif vv == 5 %expectations inflation 
    ylim([-2.7 2.3]);
    elseif vv == 7 %consumption plan
    ylim([-35 35]);
end
    
hold off

saveas(fig, strcat(presPath,irf),'pdf');
close all;
end
end
end