%% Implementation of impact and elasticity restrictions

clear all, close all; clc; dbstop if error;
rng('default');     % resets the rng to default status
addpath 'functions';

irfMedians = NaN(13,36,20);
respondents = [20 40 60 62 65 84 94 99 407 411 420 421 426 428 429 431 433 446 463 484];

%estimation = 1;
for estimation = 1:length(respondents)

clearvars -except estimation irfMedians respondents;

% choose
opt.modelName = strcat('respondent',sprintf('%d',respondents(estimation)));

% path to model folder
% path to model folder
opt.modelPath = strcat(pwd,'\');

% Read results file

load(strcat(opt.modelPath,opt.modelName,'\results.mat'));

[ output , ctmModel ] = generateOutput( y, identifiedModels, S, Z, nModelsFound, nVars, opt );

irfMedians(:,:,estimation) = output.irfMedian;

irfmedianresp0MP=irfMedians(1,13,estimation);
irfmedianresp0AS=irfMedians(1,14,estimation);
irfmedianresp0AD=irfMedians(1,15,estimation);

syms x
eqn1 = irfmedianresp0MP*x==1;
eqn2 = irfmedianresp0AS*x==1;
eqn3 = irfmedianresp0AD*x==1;

irfmultiplierMP = double(solve(eqn1,x));
irfmultiplierAS = double(solve(eqn2,x));
irfmultiplierAD = double(solve(eqn3,x));

for ii=1:6
    irfMedians(:,1+(ii-1)*nVars,estimation)=irfMedians(:,1+(ii-1)*nVars,estimation)*irfmultiplierMP;
    irfMedians(:,2+(ii-1)*nVars,estimation)=irfMedians(:,2+(ii-1)*nVars,estimation)*irfmultiplierAS;
    irfMedians(:,3+(ii-1)*nVars,estimation)=irfMedians(:,3+(ii-1)*nVars,estimation)*irfmultiplierAD;
end

end

%% Plots

opt.modelPath = strcat(pwd,'\');

% generate folder in which output can be saved

% if ~exist(strcat(opt.modelPath, '/All'),'dir')
%   mkdir(strcat(opt.modelPath, '/All'));
% end

if ~exist(strcat(opt.modelPath,'All/imgs'),'dir')
  mkdir(strcat(opt.modelPath,'All/imgs'));
end

% Plot IRFs in single plots
xAxis = 0:opt.nImpulseHorizon;
jj = 1;
for ii = 1:nVars^2
    if ii < 19
        opt.nImpulseHorizon = 8;
    else
        opt.nImpulseHorizon = 4;
    end
    if mod(ii,nVars) == 0
        shock = opt.lShocks{nVars};
    else
        shock = opt.lShocks{mod(ii,nVars)};
    end
    if ~isempty(shock)
        fig = figure(ii);
        set(gca, 'FontSize', 35, 'Position', [.12 .1 .8 .6],'Xtick',0:1:opt.nImpulseHorizon);
        hold on
        cmap = cbrewer('qual','Paired',length(respondents));
        for kk=1:length(respondents)
        plot(0:opt.nImpulseHorizon,irfMedians(1:opt.nImpulseHorizon+1,ii,kk),'-','Color',cmap(kk,:),'LineWidth', 3);
        end
        plot(0:opt.nImpulseHorizon,zeros(opt.nImpulseHorizon+1),'k-','LineWidth', 3);
        xlim([0 opt.nImpulseHorizon])
        
         if ii <= 6 %FFR
                 ylim([-6 7]);
            elseif ii > 6 && ii <= 2*6 %Inflation
                 ylim([-10 10]);
            elseif ii > 2*6 && ii <= 3*6 %unemployment
                 ylim([-2 5]);
            elseif ii > 3*6 && ii <= 4*6 %interest expectations
                ylim([-5 5]);
            elseif ii > 4*6 && ii <= 5*6 %inflation expectations
                 ylim([-4 6]);
            elseif ii > 5*6 && ii <= 6*6 %unemployment expectations
                 ylim([-5 5]);
            end
        hold off
        if opt.isPlotTitle
            title([shock ': ' opt.lVars{jj}]);
        end                
        print(fig,'-dpdf',strcat(opt.modelPath,'All/imgs/',shock,'-',opt.lVars{jj}));
    end
    if mod(ii,nVars) == 0
        jj = jj+1;
    end
end             
close all;