%% Startup
%
%clear all; close all; clc; dbstop if error; 
%rng('default');     % resets the rng to default status
%addpath 'functions';
%}

%% General program settings
% choose a unique model name

if iteration == 1
    opt.modelName = 'FigA12';
elseif iteration == 2
    opt.modelName = 'FigA13';
elseif iteration == 3
    opt.modelName = 'FigA11';
elseif iteration == 4
    opt.modelName = 'FigA14';
end

% path to model folder
opt.modelPath = strcat(pwd,'\');

% number of run
opt.runNumber = 1;

%% VAR specification and other setup 
%

% Define labels for the variables in the order in which they enter the VAR.
opt.lVars = {'FFR', 'CPI', 'U', 'INTERESTexpectations1', 'INTERESTexpectations0', 'INFLATIONexpectations1','INFLATIONexpectations0', 'OUTPUTexpectations1', 'OUTPUTexpectations0', 'CONSUMPTIONexpectations1', 'CONSUMPTIONexpectations0'};

% Define labels for the shocks you are identifying in the same order as in
%   the sign restrictions section.
opt.lShocks = {'MPshock', 'ASshock', 'ADshock', 'residual8', 'residual7', 'residual6', 'residual5', 'residual4', 'residual3', 'residual2', 'residual1'};

% Define start date and end date of the dataset
opt.startDate = '01-31-1985';
opt.endDate = '06-30-2007';

% Define the lag order.
opt.nLags = 2;           

% Define the horizon over which impulse responses are calculated
% (0 = only contemporary, 1 = contemporary + horizon 1).
opt.nImpulseHorizon = 24;         

% Define the horizon over which the closest-to-median impulse response is
% calculated. (only contemporary: 0)
opt.nCTMHorizon = 24;

% When looking for the closest-to-median impulse response, use only the
% impulse responses associtated with a shock with zero or sign
% restrictions. (1 = Yes, 0 = No, use all impulse responses)
opt.narrowCTMSearch = 1;

% Use a constant in the estimation of the VAR (1 = Yes, 0 = No).
opt.hasConstant = 1;

% Estimation Method
%   choose from 'OLS', 'diffuse'
opt.estimationMethod = 'diffuse';

% draws from BVAR to generate posterior distribution
% this will only be relevant when the estimation method is non-analytical
opt.nDrawsFromBvar = 1000;

% maximum horizon of sign restrictions (only contemporary: 0)
opt.nMaxSignHorizon = 3;

% Number of model draws. This is only used if drawFromPosterior == 1.
opt.nModelDraws = 1;

% number of Householder transformations per model draw
opt.nTransformationsPerDraw = 1000;

% draw from posterior distribution when working through
% sign restrictions (1 = Yes, 0 = work through all draws)
opt.drawFromPosterior = 0;

% if a sign restriction is fullfilled for the negative of a Q column
% transform this column of Q to it's negative.
% if this option is 0 the diagonal of Q will be normalized to have a
% positive diagonal.
opt.checkNegativeQ = 1;

% keep all valid transformations when transforming one particular draw from
% the posterior (1 = Yes, 0 = only transform until you find a match).
opt.keepAllValid = 0;

% Stop search-loop, when a certain number of models fulfill restrictions
% (Default = 10000000).
opt.nMatches = 1000;

% No transformations (for debugging) (1 = Yes, 0 = No)
opt.isNoTransform = 0;

% Calculate the FEVD for all models (1 = Yes, 0 = No) (Default = 0)
% this slows down the program.
opt.isFevdTable = 1;

% Save IRFs in csv (Default = 0)
opt.isIRFtable = 1;

% Save structural shocks in .mat-File (Default = 0)
opt.isStructShockTable = 0;

% Save results in results.mat (Default = 0)
opt.isSaveResults = 1;

% Plotting Options
% ================
% Generate impulse response plots (Default = 0)
opt.isImpulsePlots = 1;

% Plot CTM (default = 1)
opt.isPlotCTM = 1;

% number of randomly drawn models to include in the impulse response plots
% (0 = none)
opt.nPlotRandomModels = 0;

% Generate structural shock plots
opt.isStructShockPlots = 0;

% Generate historical decomposition plots
% takes a lot of time
opt.isHistDecomp = 0;

% Generate forecast error variance decomposition plots
opt.isFevdPlots = 0;

% Print labels above the plots
opt.isPlotTitle = 0;





% consistency checks  
if opt.drawFromPosterior == 0
	opt.nModelDraws = opt.nDrawsFromBvar;
end

%}

%% Data Setup
%

% Read in the data here. Assign the final data to be used in the analysis 
%   to y. 

% 'FFR', 'CPI', 'U', 'INTERESTexpectations1', 'INTERESTexpectations0', 'INFLATIONexpectations1','INFLATIONexpectations0', 'OUTPUTexpectations1', 'OUTPUTexpectations0', 'CONSUMPTIONexpectations1', 'CONSUMPTIONexpectations0'
% poor old degree female
    data(:,1) = xlsread('var_data.xls','AK2:AK271'); %FFR
    data(:,2) = xlsread('var_data.xls','AL2:AL271'); %inflation
    data(:,3) = xlsread('var_data.xls','AM2:AM271'); %U


if iteration == 1
    data(:,4) = xlsread('var_data.xls','H2:H271'); %'INTERESTexpectations1'
    data(:,5) = xlsread('var_data.xls','D2:D271'); %'INTERESTexpectations0'
    data(:,6) = xlsread('var_data.xls','K2:K271'); %'INFLATIONexpectations1'
    data(:,7) = xlsread('var_data.xls','G2:G271'); %'INFLATIONexpectations0'
    data(:,8) = xlsread('var_data.xls','I2:I271'); %'OUTPUTexpectations1'
    data(:,9) = xlsread('var_data.xls','E2:E271'); %'OUTPUTexpectations0'
    data(:,10) = xlsread('var_data.xls','J2:J271'); %'CONSUMPTIONexpectations1'
    data(:,11) = xlsread('var_data.xls','F2:F271'); %, 'CONSUMPTIONexpectations0'
elseif iteration == 2
    data(:,4) = xlsread('var_data.xls','P2:P271'); %'INTERESTexpectations1'
    data(:,5) = xlsread('var_data.xls','L2:L271'); %'INTERESTexpectations0'
    data(:,6) = xlsread('var_data.xls','S2:S271'); %'INFLATIONexpectations1'
    data(:,7) = xlsread('var_data.xls','O2:O271'); %'INFLATIONexpectations0'
    data(:,8) = xlsread('var_data.xls','Q2:Q271'); %'OUTPUTexpectations1'
    data(:,9) = xlsread('var_data.xls','M2:M271'); %'OUTPUTexpectations0'
    data(:,10) = xlsread('var_data.xls','R2:R271'); %'CONSUMPTIONexpectations1'
    data(:,11) = xlsread('var_data.xls','N2:N271'); %, 'CONSUMPTIONexpectations0'
elseif iteration == 3
    data(:,4) = xlsread('var_data.xls','X2:X271'); %'INTERESTexpectations1'
    data(:,5) = xlsread('var_data.xls','T2:T271'); %'INTERESTexpectations0'
    data(:,6) = xlsread('var_data.xls','AA2:AA271'); %'INFLATIONexpectations1'
    data(:,7) = xlsread('var_data.xls','W2:W271'); %'INFLATIONexpectations0'
    data(:,8) = xlsread('var_data.xls','Y2:Y271'); %'OUTPUTexpectations1'
    data(:,9) = xlsread('var_data.xls','U2:U271'); %'OUTPUTexpectations0'
    data(:,10) = xlsread('var_data.xls','Z2:Z271'); %'CONSUMPTIONexpectations1'
    data(:,11) = xlsread('var_data.xls','V2:V271'); %, 'CONSUMPTIONexpectations0'
elseif iteration == 4
    data(:,4) = xlsread('var_data.xls','AF2:AF271'); %'INTERESTexpectations1'
    data(:,5) = xlsread('var_data.xls','AB2:AB271'); %'INTERESTexpectations0'
    data(:,6) = xlsread('var_data.xls','AI2:AI271'); %'INFLATIONexpectations1'
    data(:,7) = xlsread('var_data.xls','AE2:AE271'); %'INFLATIONexpectations0'
    data(:,8) = xlsread('var_data.xls','AG2:AG271'); %'OUTPUTexpectations1'
    data(:,9) = xlsread('var_data.xls','AC2:AC271'); %'OUTPUTexpectations0'
    data(:,10) = xlsread('var_data.xls','AH2:AH271'); %'CONSUMPTIONexpectations1'
    data(:,11) = xlsread('var_data.xls','AD2:AD271'); %, 'CONSUMPTIONexpectations0'
end

y = data;

[t,nVars] = size(y);
%}

%% Sign Restriction Setup
%

S = zeros(2,nVars*(opt.nMaxSignHorizon + 1),nVars);
Z = zeros(2,nVars*(opt.nMaxSignHorizon + 1),nVars);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SIGN RESTRICTION DEFINITION
% -----------------------------------------------------------------------
% Explanation:
% ===========
%   The sign and zero restrictions are implemented using selection matrices 
%   (S for sign restrictions and Z for zero restrictions).
%   S and Z are three dimensional arrays. 
%   - The first dimension is the row of the selection matrix. For each 
%   shock it should be incremented by one for with each restriction imposed 
%   to identify the shock starting at 1 for the first restriction.
%   - The second dimension is the column of the selection matrix. It
%   selects the variable on which the restriction should be set as well as
%   the horizon. For example the second variable at horizon 0 is selected
%   with 2, the second variable at horizon 1 is selected with 2 + nVars, 
%   the second variable at horizon 2 is selected with 2 + 2*nVars, and the 
%   second variable at horizon h is selected with 2 + h*nVars, where nVars 
%   is the number of variables in the system.
%   - The third dimension is the number of the shock. For the first shock
%   you want to identify pick 1, for the second 2, ...
%   - The matrix SN is used to impose a restriction which demands the
%   impulse response to be above or below zero by a certain amount, e.g.,
%   to restrict the contemporaneous response of variable 2 to shock 6 to be
%   above 2 in addition to the sign restriction S(1,2,6) = 1 the
%   restriction SN(1,2,6) = 2 would be set.
% Examples:
% ========
%   first shock: zero restriction on variables 1 and 2 at horizon 0
%       Z(1,1,1) = 1;
%       Z(2,2,1) = 1;
%   second shock: negative reaction of variable 1 up to maximum horizon
%     for ii = 1:(nMaxSignHorizon+1) 
%         S(ii,1+nVars*(ii-1),2) = -1;
%     end
%   second shock: positive reaction of variable 4 at horizons 0 and 1
%       S(nMaxSignHorizon+2,4,2);
%       S(nMaxSignHorizon+3,4+nVars,2);
%       Note: As we already nMaxSignHorizon+1 restrictions for the second
%       shock we have to start at nMaxSignHorizon+2.
%   For shocks without restrictions (residual shocks) nothing has to be
%   done.
% -----------------------------------------------------------------------

% Order: {'FFR', 'CPI', 'U', 'INTERESTexpectation', 'INFLATIONexpectations', 'OUTPUTexpectations'}

% MP Shock

 Z(1,4,1) = 1;
 Z(2,5,1) = 1;
 Z(3,6,1) = 1;
 Z(4,7,1) = 1;
 Z(5,8,1) = 1;
 Z(6,9,1) = 1;
 Z(7,10,1) = 1;
 Z(8,11,1) = 1;

 % positive response of FFR
 
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii,1+nVars*(ii-1),1) = 1;
 end
 
 % negative response of prices
 
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+opt.nMaxSignHorizon+1,2+nVars*(ii-1),1) = -1;
 end
 
 % positive response of U
 

 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+2*(opt.nMaxSignHorizon+1),3+nVars*(ii-1),1) = 1;
 end
 
 
% AS Shock

 Z(1,4,2) = 1;
 Z(2,5,2) = 1;
 Z(3,6,2) = 1;
 Z(4,7,2) = 1;
 Z(5,8,2) = 1;
 Z(6,9,2) = 1;
 Z(7,10,2) = 1;
 Z(8,11,2) = 1;

 
 % positive response of FFR
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii,1+nVars*(ii-1),2) = 1;
 end
 
 % positive response of CPI
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+opt.nMaxSignHorizon+1,2+nVars*(ii-1),2) = 1;
 end
 
 % positive response of U
 

 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+2*(opt.nMaxSignHorizon+1),3+nVars*(ii-1),2) = 1;
 end
 
 % AD Shock
 
 Z(1,4,3) = 1;
 Z(2,5,3) = 1;
 Z(3,6,3) = 1;
 Z(4,7,3) = 1;
 Z(5,8,3) = 1;
 Z(6,9,3) = 1;
 Z(7,10,3) = 1;
 Z(8,11,3) = 1;
 
 % negative response of FFR
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii,1+nVars*(ii-1),3) = -1;
 end
 
 % negative response of CPI
 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+opt.nMaxSignHorizon+1,2+nVars*(ii-1),3) = -1;
 end
 
  % positive response of U

 for ii = 1:(opt.nMaxSignHorizon+1)
     S(ii+2*(opt.nMaxSignHorizon+1),3+nVars*(ii-1),3) = 1;
 end
 
  % Residual 1
 %Z(1,5,4) = 1;
 %Z(2,6,4) = 1;
 
 S(1,4,4)= 1;
 
 % Resudual 2
 
 %Z(1,6,5) = 1;
 
 S(1,5,5) = 1;
 
 %Residual 3
 
 S(1,6,6) = 1;
 
 %Residual 4
 
 S(1,7,7) = 1;
 
 S(1,8,8) = 1;
 
 S(1,9,9) = 1;
 
 S(1,10,10) = 1;
 
 S(1,11,11) = 1;

%%% DON'T EDIT NEXT LINE
SN = zeros(size(S));
%%%

% SN(1,6,6) = 2;
% SN(1,6,7) = 2;

%}

signrestrictions